@@ -152,25 +152,6 @@ class GitHubCommand(GitCommand):
     """Base GitHub command.
     """
 
-    def get_issues(self, **parameters):
-        """Get a list of issues, ordered by milestone.
-
-        :param parameters: Parameter keyword-arguments.
-        """
-        ret_val = []
-        milestones = self.github.get_milestones()
-
-        for milestone in milestones:
-            parameters["milestone"] = milestone.number
-            issues = self.github.get_issues(**parameters)
-            ret_val.extend(issues)
-
-        parameters["milestone"] = None
-        issues = self.github.get_issues(**parameters)
-        ret_val.extend(issues)
-
-        return ret_val
-
     @cached_property
     def github(self):
         """GitHub accessor.
@@ -179,27 +160,6 @@ class GitHubCommand(GitCommand):
 
         return GitHubService(self.git, token)
 
-    @cached_property
-    def issue(self):
-        """Current branch issue accessor.
-        """
-        configuration = self.git.get_configuration("branch",
-                self.git.branch.name)
-
-        if configuration:
-            try:
-                number = configuration["issue"]
-                ret_val = self.github.get_issue(number)
-            except KeyError:
-                ret_val = None
-        else:
-            ret_val = None
-
-        if not ret_val:
-            exit("fatal: Not an issue branch.")
-
-        return ret_val
-
 
 class CommitCommand(BaseCommand):
     """Git prepare commit message hook.
@@ -263,7 +223,7 @@ class CommitCommand(BaseCommand):
             exit()
 
 
-class FinishCommand(GitCommand):
+class FinishCommand(GitHubCommand):
     """Finish work on a branch.
 
     :param parser: Command-line argument parser.
@@ -321,6 +281,15 @@ class FinishCommand(GitCommand):
             message = "error: Attempted finish from non-integration branch; switch to '{0}'."  # NOQA
             exit(message.format(branch))
 
+    def finalize(self):
+        """Finalize this finish command.
+        """
+        try:
+            self.github.remove_branch(self.namespace.branch)
+            self.git.prune_branches()
+        except GitHubException:
+            pass
+
 
 class InitCommand(GitCommand):
     """Initialize a git repository for use with continuity.
